==> recruit-drop-list-1.0.19.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import "core-js/modules/web.dom.iterable";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _assertThisInitialized from "@babel/runtime/helpers/assertThisInitialized";
import React, { Component } from 'react';
import { findDOMNode } from 'react-dom';
import TagInput from 'recruit-tag-input';
import DropList from './dropList';
import CommonMount from '@beisen-platform/ethos/lib/CommonMount';
import BaseButton from '@beisen-platform/ethos/lib/BaseButton';
import CommonPop from '@beisen-platform/ethos/lib/CommonPop';
import CreatePage from './createPage';
import './index.css';

var _default =
/*#__PURE__*/
function (_Component) {
  _inherits(_default, _Component);

  function _default(props) {
    var _this;

    _classCallCheck(this, _default);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(_default).call(this, props));
    _this.state = {
      popShow: props.showPop == undefined ? false : props.showPop,
      children: props.children && props.children.length > 0 ? props.children : [],
      defaultItems: props.defaultItems && props.defaultItems.length > 0 ? props.defaultItems : [],
      isEmailError: false,
      keepActive: false
    };
    _this.CommonMount = new CommonMount({
      containerId: 'DropdownList_ul',
      // 容器ID
      follow: true,
      // 是否滚动跟随，默认true
      fixed: true // 定位：fixed，false时为absolute

    });
    _this.onClose = _this.onClose.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.handleClick = _this.handleClick.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.createUserItem = _this.createUserItem.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.submitPop = _this.submitPop.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.closePop = _this.closePop.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    return _this;
  }

  _createClass(_default, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      if (nextProps.children !== this.props.children) {
        this.setState({
          children: nextProps.children
        });
      }

      if (nextProps.defaultItems !== this.props.defaultItems) {
        this.setState({
          defaultItems: nextProps.defaultItems
        });
      }

      if (nextProps.isEmailError !== this.props.isEmailError) {
        this.setState({
          isEmailError: nextProps.isEmailError
        });
      }

      if (nextProps.showPop !== this.props.showPop) {
        this.setState({
          popShow: nextProps.showPop
        });
      }
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      var dom = document.getElementsByClassName('tag-input-is-active')[0];

      if (dom && this.props.autoShowPanel && this.state.keepActive) {
        this.renderDom(dom.parentNode);
      }

      ;
    }
  }, {
    key: "addItems",
    value: function addItems(event, val) {
      var single = this.props.single;
      var duplicate = [];
      this.state.defaultItems.forEach(function (item) {
        if (val.value == item.value) duplicate.push(item);
      });
      if (duplicate.length > 0) return false;
      var item = {
        text: val.text[0] + (val.text[1] ? '(' + val.text[1] + ')' : ''),
        value: val.value
      };

      if (single || single == undefined) {
        this.state.defaultItems = [item];
      } else {
        var defaultItems = _toConsumableArray(this.state.defaultItems);

        defaultItems.push(item);
        this.state.defaultItems = defaultItems;
      }

      this.setState(this.state);
      this.props.onSureClick && this.props.onSureClick(event, this.state.defaultItems);
    }
  }, {
    key: "renderDom",
    value: function renderDom(tar) {
      var self = this;
      var dropdownDate = {
        limitCount: 10,
        multiple: true,
        children: this.state.children,
        dropdownWidth: tar.offsetWidth,
        hasSearch: false,
        itemClick: function itemClick(event, val) {
          self.state.keepActive = false;
          self.CommonMount.unmountBox();
          self.addItems(event, val);
        }
      };
      var dropHeight;
      var dropcount = this.props.children.length > 10 ? 10 : this.props.children.length;
      dropHeight = this.props.children.length > 10 ? 280 : dropcount * 28;
      var showAutoUl = React.createElement(DropList, dropdownDate);
      this.CommonMount.renderDom('mount-box-dropdownlist', // wrap's classname & id
      showAutoUl, // content dom
      tar, // 跟随目标
      [tar, //挂载目标节点
      {
        // 挂载元素宽高 {width: '', height: ''}
        width: tar.clientWidth,
        // 挂载宽度
        height: dropHeight
      }, 28], true, //labeL和input框是否为竖向结构，会留出对应的label空间
      0, //水平向左偏移量，为负数则向右
      false, //弹层靠左靠右模式，默认为false 靠左模式
      100, //window.onresize执行时间，默认100ms
      false, //输入框高度
      99999 //自定义zindex
      );
    }
  }, {
    key: "onClose",
    value: function onClose(event) {
      try {
        findDOMNode(this);
      } catch (e) {
        this.CommonMount.unmountBox();
        this.setState({
          keepActive: false
        });
        document.removeEventListener('mousedown', this.onClose);
        this.props.onClose && this.props.onClose("close");
        return;
      }

      var area = document.getElementById("DropdownList_ul");

      if (area && !area.contains(event.target)) {
        // if (event.target.className.indexOf('sys-icon-close')>-1|| event.target.className.indexOf('u-icon')>-1 || event.target.tagName === 'BODY') return;
        this.CommonMount.unmountBox();
        this.setState({
          keepActive: false
        });
        document.removeEventListener('mousedown', this.onClose);
        this.props.onClose && this.props.onClose("close");
      }
    }
  }, {
    key: "handleClick",
    value: function handleClick(event, value) {
      var dom = event.target.parentNode.parentNode.parentNode;
      this.renderDom(dom);
      this.setState({
        keepActive: true
      });
      document.removeEventListener('mousedown', this.onClose);
      document.addEventListener('mousedown', this.onClose);
      this.props.inputOnClick && this.props.inputOnClick(event, value);
    }
  }, {
    key: "handleDelete",
    value: function handleDelete(event, value) {
      this.props.onDeleteItem && this.props.onDeleteItem(event, value);
    }
  }, {
    key: "createUserItem",
    value: function createUserItem() {
      this.setState({
        popShow: true
      });
    }
  }, {
    key: "submitPop",
    value: function submitPop() {
      this.refs.createPage.validateAll();
      var _this$refs$createPage = this.refs.createPage.state,
          nameValue = _this$refs$createPage.nameValue,
          emailValue = _this$refs$createPage.emailValue,
          phoneValue = _this$refs$createPage.phoneValue,
          nameRequired = _this$refs$createPage.nameRequired,
          emailRequired = _this$refs$createPage.emailRequired,
          wrongEmail = _this$refs$createPage.wrongEmail,
          wrongPhone = _this$refs$createPage.wrongPhone;

      if (wrongEmail || wrongPhone || nameValue == '' || emailValue == '') {
        return false;
      }

      this.props.throwCreateData && this.props.throwCreateData({
        name: nameValue,
        email: emailValue,
        phone: phoneValue
      });
      if (this.props.showPop) return false;
      this.closePop();
    }
  }, {
    key: "closePop",
    value: function closePop() {
      this.setState({
        popShow: false
      });
    }
  }, {
    key: "render",
    value: function render() {
      var self = this;
      var _this$props = this.props,
          maxCount = _this$props.maxCount,
          onSearch = _this$props.onSearch,
          title = _this$props.title,
          isRequired = _this$props.isRequired,
          lablePos = _this$props.lablePos,
          lableText = _this$props.lableText,
          errorStatus = _this$props.errorStatus,
          errorMessage = _this$props.errorMessage,
          disableKeyDown = _this$props.disableKeyDown,
          canCreate = _this$props.canCreate,
          disableInput = _this$props.disableInput,
          createBtnText = _this$props.createBtnText,
          isEmailError = _this$props.isEmailError,
          emailErrorTip = _this$props.emailErrorTip,
          validateEmail = _this$props.validateEmail;
      var btnOpt1 = {
        bsStyle: "weaken",
        bsSize: "default",
        title: "取消"
        /**显示文本(string)**/
        ,
        onClick: function onClick(target, _onClick, btnInfo) {
          self.closePop();
        }
        /**点击后事件回调**/

      };
      var btnOpt2 = {
        bsStyle: "default",
        bsSize: "default",
        title: "确定"
        /**显示文本(string)**/
        ,
        onClick: function onClick(target, _onClick2, btnInfo) {
          self.submitPop();
        }
        /**点击后事件回调**/

      };
      var footerContent = React.createElement("div", {
        className: "rec-pop-footer"
      }, React.createElement("span", {
        className: "rec-cancleBtn"
      }, React.createElement(BaseButton, btnOpt1)), React.createElement("span", {
        className: "rec-submitBtn"
      }, React.createElement(BaseButton, btnOpt2)));
      var inputOption = {
        maxCount: maxCount,
        canCreate: canCreate,
        createBtnText: createBtnText,
        disableKeyDown: disableKeyDown //是否禁用回车添加项功能
        ,
        disableInput: disableInput,
        defaultItems: this.state.defaultItems,
        title: title //label文本
        ,
        isRequired: isRequired,
        lablePos: lablePos //label位置，true时在左边，false在上边
        ,
        lableText: lableText //label中文字对齐方式，true左对齐，false右对齐 
        ,
        errorStatus: errorStatus,
        errorMessage: errorMessage,
        isDropList: true,
        onClick: function onClick(event, status, value) {
          self.handleClick(event, value);
        },
        onFocus: function onFocus(event, status, value) {},
        onChange: function onChange(event, status, value) {
          onSearch(event, event.target.value);
        },
        onBlur: function onBlur(event, status, value) {},
        addItemCallBack: function addItemCallBack(event, status, value) {},
        deleteItemCallBack: function deleteItemCallBack(event, status, value) {
          self.handleDelete(event, value);
        },
        createNewItem: function createNewItem() {
          self.createUserItem();
        }
      };
      var popOption = {
        popShow: this.state.popShow,
        title: "新建" //头部名称
        ,
        hasHeader: true //是否显示头部
        ,
        hasFooter: true //是否显示底部，含有确定取消按钮
        ,
        dataType: "component" //string 字符串 component 组件
        ,
        data: "" //需要传入引入组件的数据
        ,
        hasRender: true // 传入的组件是否已渲染，只有当dateType为component时有效
        ,
        animation: true //是否用弹窗的动效
        ,
        dragDisabled: false //是否可以拖拽弹窗，默认true为禁止拖拽，false为未禁用拖拽
        ,
        contentResizeListener: true //开启监听弹层内容高度变化
        ,
        footerContent: footerContent // ,headerContent: <div></div> //自定义渲染头部
        ,
        customStyle: {
          'zIndex': '100000',
          'maxHeight': '300px'
        },
        bodyMask: true,
        subBtnShow: false //默认为true
        ,
        cloBtnShow: false //默认为true
        ,
        showMask: true //默认为false
        ,
        isLookUpV2: true //平台专用
        ,
        fixPos: true //专门解决在win10 IE下非iframe页面下弹窗错位问题
        ,
        preSubmit: function preSubmit() {} // 点击确定按钮前会调用的方法，非必须
        ,
        preCancel: function preCancel() {} //点击取消按钮前调用的方法，非必须

      };
      var DemoComponent = React.createElement(CreatePage, {
        ref: "createPage",
        isEmailError: isEmailError,
        emailErrorTip: emailErrorTip || '',
        validateEmail: validateEmail
      });
      var CommonPopCmp = this.state.popShow ? React.createElement(CommonPop, _extends({}, popOption, {
        PopComponent: DemoComponent,
        closePop: this.closePop
      })) : null;
      return React.createElement("div", null, React.createElement(TagInput, _extends({
        ref: "tagInput"
      }, inputOption)), CommonPopCmp);
    }
  }]);

  return _default;
}(Component);

export { _default as default };

==> recruit-drop-list-1.0.24.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import "core-js/modules/web.dom.iterable";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _assertThisInitialized from "@babel/runtime/helpers/assertThisInitialized";
import React, { Component } from 'react';
import { findDOMNode } from 'react-dom';
import TagInput from 'recruit-tag-input';
import DropList from './dropList';
import CommonMount from '@beisen-platform/ethos/lib/CommonMount';
import BaseButton from '@beisen-platform/ethos/lib/BaseButton';
import CommonPop from '@beisen-platform/ethos/lib/CommonPop';
import CreatePage from './createPage';
import './index.css';

var _default =
/*#__PURE__*/
function (_Component) {
  _inherits(_default, _Component);

  function _default(props) {
    var _this;

    _classCallCheck(this, _default);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(_default).call(this, props));
    _this.state = {
      popShow: props.showPop == undefined ? false : props.showPop,
      children: props.children && props.children.length > 0 ? props.children : [],
      defaultItems: props.defaultItems && props.defaultItems.length > 0 ? props.defaultItems : [],
      isEmailError: false,
      keepActive: false
    };
    _this.CommonMount = new CommonMount({
      containerId: 'DropdownList_ul',
      // 容器ID
      follow: true,
      // 是否滚动跟随，默认true
      fixed: true // 定位：fixed，false时为absolute

    });
    _this.onClose = _this.onClose.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.handleClick = _this.handleClick.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.createUserItem = _this.createUserItem.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.submitPop = _this.submitPop.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.closePop = _this.closePop.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    return _this;
  }

  _createClass(_default, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      if (nextProps.children !== this.props.children) {
        this.setState({
          children: nextProps.children
        });
      }

      if (nextProps.defaultItems !== this.props.defaultItems) {
        this.setState({
          defaultItems: nextProps.defaultItems
        });
      }

      if (nextProps.isEmailError !== this.props.isEmailError) {
        this.setState({
          isEmailError: nextProps.isEmailError
        });
      }

      if (nextProps.showPop !== this.props.showPop) {
        this.setState({
          popShow: nextProps.showPop
        });
      }
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      var dom = document.getElementsByClassName('tag-input-is-active')[0];

      if (dom && this.props.autoShowPanel && this.state.keepActive) {
        this.renderDom(dom.parentNode);
      }

      ;
    }
  }, {
    key: "addItems",
    value: function addItems(event, val) {
      var single = this.props.single;
      var duplicate = [];
      this.state.defaultItems.forEach(function (item) {
        if (val.value == item.value) duplicate.push(item);
      });
      if (duplicate.length > 0) return false;
      var item = {
        text: val.text[0] + (val.text[1] ? '(' + val.text[1] + ')' : ''),
        value: val.value
      };

      if (single || single == undefined) {
        this.state.defaultItems = [item];
      } else {
        var defaultItems = _toConsumableArray(this.state.defaultItems);

        defaultItems.push(item);
        this.state.defaultItems = defaultItems;
      }

      this.setState(this.state);
      this.props.onSureClick && this.props.onSureClick(event, this.state.defaultItems);
    }
  }, {
    key: "renderDom",
    value: function renderDom(tar) {
      var self = this;
      var dropdownDate = {
        limitCount: 10,
        multiple: true,
        children: this.state.children,
        dropdownWidth: tar.offsetWidth,
        hasSearch: false,
        itemClick: function itemClick(event, val) {
          self.state.keepActive = false;
          self.CommonMount.unmountBox();
          self.addItems(event, val);
        }
      };
      var dropHeight;
      var dropcount = this.props.children.length > 10 ? 10 : this.props.children.length;
      dropHeight = this.props.children.length > 10 ? 280 : dropcount * 28;
      var showAutoUl = React.createElement(DropList, dropdownDate);
      this.CommonMount.renderDom('recruit-dropdownlist', // wrap's classname & id
      showAutoUl, // content dom
      tar, // 跟随目标
      [tar, //挂载目标节点
      {
        // 挂载元素宽高 {width: '', height: ''}
        width: tar.clientWidth,
        // 挂载宽度
        height: dropHeight
      }, 28], true, //labeL和input框是否为竖向结构，会留出对应的label空间
      0, //水平向左偏移量，为负数则向右
      false, //弹层靠左靠右模式，默认为false 靠左模式
      100, //window.onresize执行时间，默认100ms
      false, //输入框高度
      99999 //自定义zindex
      ); // document.getElementsByClassName('recruit-dropdownlist')[0].style.height = dropHeight + 'px';
    }
  }, {
    key: "onClose",
    value: function onClose(event) {
      try {
        findDOMNode(this);
      } catch (e) {
        this.CommonMount.unmountBox();
        this.setState({
          keepActive: false
        });
        document.removeEventListener('mousedown', this.onClose);
        this.props.onClose && this.props.onClose("close");
        return;
      }

      var area = document.getElementById("DropdownList_ul");

      if (area && !area.contains(event.target)) {
        // if (event.target.className.indexOf('sys-icon-close')>-1|| event.target.className.indexOf('u-icon')>-1 || event.target.tagName === 'BODY') return;
        this.CommonMount.unmountBox();
        this.setState({
          keepActive: false
        });
        document.removeEventListener('mousedown', this.onClose);
        this.props.onClose && this.props.onClose("close");
      }
    }
  }, {
    key: "handleClick",
    value: function handleClick(event, value) {
      var dom = event.target.parentNode.parentNode.parentNode;
      this.renderDom(dom);
      this.setState({
        keepActive: true
      });
      document.removeEventListener('mousedown', this.onClose);
      document.addEventListener('mousedown', this.onClose);
      this.props.inputOnClick && this.props.inputOnClick(event, value);
    }
  }, {
    key: "handleDelete",
    value: function handleDelete(event, value) {
      this.props.onDeleteItem && this.props.onDeleteItem(event, value);
    }
  }, {
    key: "createUserItem",
    value: function createUserItem() {
      this.setState({
        popShow: true
      });
    }
  }, {
    key: "submitPop",
    value: function submitPop() {
      this.refs.createPage.validateAll();
      var _this$refs$createPage = this.refs.createPage.state,
          nameValue = _this$refs$createPage.nameValue,
          emailValue = _this$refs$createPage.emailValue,
          phoneValue = _this$refs$createPage.phoneValue,
          nameRequired = _this$refs$createPage.nameRequired,
          emailRequired = _this$refs$createPage.emailRequired,
          wrongEmail = _this$refs$createPage.wrongEmail,
          wrongPhone = _this$refs$createPage.wrongPhone;

      if (wrongEmail || wrongPhone || nameValue == '' || emailValue == '') {
        return false;
      }

      this.props.throwCreateData && this.props.throwCreateData({
        name: nameValue,
        email: emailValue,
        phone: phoneValue
      });
      if (this.props.showPop) return false;
      this.closePop();
    }
  }, {
    key: "closePop",
    value: function closePop() {
      this.setState({
        popShow: false
      });
    }
  }, {
    key: "render",
    value: function render() {
      var self = this;
      var _this$props = this.props,
          maxCount = _this$props.maxCount,
          onSearch = _this$props.onSearch,
          title = _this$props.title,
          isRequired = _this$props.isRequired,
          lablePos = _this$props.lablePos,
          lableText = _this$props.lableText,
          errorStatus = _this$props.errorStatus,
          errorMessage = _this$props.errorMessage,
          disableKeyDown = _this$props.disableKeyDown,
          canCreate = _this$props.canCreate,
          disableInput = _this$props.disableInput,
          createBtnText = _this$props.createBtnText,
          isEmailError = _this$props.isEmailError,
          emailErrorTip = _this$props.emailErrorTip,
          validateEmail = _this$props.validateEmail;
      var btnOpt1 = {
        bsStyle: "weaken",
        bsSize: "default",
        title: "取消"
        /**显示文本(string)**/
        ,
        onClick: function onClick(target, _onClick, btnInfo) {
          self.closePop();
        }
        /**点击后事件回调**/

      };
      var btnOpt2 = {
        bsStyle: "default",
        bsSize: "default",
        title: "确定"
        /**显示文本(string)**/
        ,
        onClick: function onClick(target, _onClick2, btnInfo) {
          self.submitPop();
        }
        /**点击后事件回调**/

      };
      var footerContent = React.createElement("div", {
        className: "rec-pop-footer"
      }, React.createElement("span", {
        className: "rec-cancleBtn"
      }, React.createElement(BaseButton, btnOpt1)), React.createElement("span", {
        className: "rec-submitBtn"
      }, React.createElement(BaseButton, btnOpt2)));
      var inputOption = {
        maxCount: maxCount,
        canCreate: canCreate,
        createBtnText: createBtnText,
        disableKeyDown: disableKeyDown //是否禁用回车添加项功能
        ,
        disableInput: disableInput,
        defaultItems: this.state.defaultItems,
        title: title //label文本
        ,
        isRequired: isRequired,
        lablePos: lablePos //label位置，true时在左边，false在上边
        ,
        lableText: lableText //label中文字对齐方式，true左对齐，false右对齐 
        ,
        errorStatus: errorStatus,
        errorMessage: errorMessage,
        isDropList: true,
        onClick: function onClick(event, status, value) {
          self.handleClick(event, value);
        },
        onFocus: function onFocus(event, status, value) {},
        onChange: function onChange(event, status, value) {
          onSearch(event, event.target.value);
        },
        onBlur: function onBlur(event, status, value) {},
        addItemCallBack: function addItemCallBack(event, status, value) {},
        deleteItemCallBack: function deleteItemCallBack(event, status, value) {
          self.handleDelete(event, value);
        },
        createNewItem: function createNewItem() {
          self.createUserItem();
        }
      };
      var popOption = {
        popShow: this.state.popShow,
        title: "新建" //头部名称
        ,
        hasHeader: true //是否显示头部
        ,
        hasFooter: true //是否显示底部，含有确定取消按钮
        ,
        dataType: "component" //string 字符串 component 组件
        ,
        data: "" //需要传入引入组件的数据
        ,
        hasRender: true // 传入的组件是否已渲染，只有当dateType为component时有效
        ,
        animation: true //是否用弹窗的动效
        ,
        dragDisabled: false //是否可以拖拽弹窗，默认true为禁止拖拽，false为未禁用拖拽
        ,
        contentResizeListener: true //开启监听弹层内容高度变化
        ,
        footerContent: footerContent // ,headerContent: <div></div> //自定义渲染头部
        ,
        customStyle: {
          'zIndex': '100000',
          'maxHeight': '300px'
        },
        bodyMask: true,
        subBtnShow: false //默认为true
        ,
        cloBtnShow: false //默认为true
        ,
        showMask: true //默认为false
        ,
        isLookUpV2: true //平台专用
        ,
        fixPos: true //专门解决在win10 IE下非iframe页面下弹窗错位问题
        ,
        preSubmit: function preSubmit() {} // 点击确定按钮前会调用的方法，非必须
        ,
        preCancel: function preCancel() {} //点击取消按钮前调用的方法，非必须

      };
      var DemoComponent = React.createElement(CreatePage, {
        ref: "createPage",
        isEmailError: isEmailError,
        emailErrorTip: emailErrorTip || '',
        validateEmail: validateEmail
      });
      var CommonPopCmp = this.state.popShow ? React.createElement(CommonPop, _extends({}, popOption, {
        PopComponent: DemoComponent,
        closePop: this.closePop
      })) : null;
      return React.createElement("div", null, React.createElement(TagInput, _extends({
        ref: "tagInput"
      }, inputOption)), CommonPopCmp);
    }
  }]);

  return _default;
}(Component);

export { _default as default };
